@@ -43,14 +43,14 @@
 #' @source HYDAT
 #' @export
 
-
-
-hy_daily_levels <- function(station_number = NULL,
-                            hydat_path = NULL,
-                            prov_terr_state_loc = NULL,
-                            start_date = NULL,
-                            end_date = NULL,
-                            symbol_output = "code") {
+hy_daily_levels <- function(
+  station_number = NULL,
+  hydat_path = NULL,
+  prov_terr_state_loc = NULL,
+  start_date = NULL,
+  end_date = NULL,
+  symbol_output = "code"
+) {
   ## Determine which dates should be queried
   dates_null <- date_check(start_date, end_date)
 
@@ -77,12 +77,24 @@ hy_daily_levels <- function(station_number = NULL,
   ## Do the initial subset to take advantage of dbplyr only issuing sql query when it has too
 
   ## by year
-  if (!dates_null[["start_is_null"]]) dly_levels <- dplyr::filter(dly_levels, !!sym_YEAR >= lubridate::year(start_date))
-  if (!dates_null[["end_is_null"]]) dly_levels <- dplyr::filter(dly_levels, !!sym_YEAR <= lubridate::year(end_date))
+  if (!dates_null[["start_is_null"]])
+    dly_levels <- dplyr::filter(
+      dly_levels,
+      !!sym_YEAR >= lubridate::year(start_date)
+    )
+  if (!dates_null[["end_is_null"]])
+    dly_levels <- dplyr::filter(
+      dly_levels,
+      !!sym_YEAR <= lubridate::year(end_date)
+    )
 
   dly_levels <- dplyr::select(
-    dly_levels, STATION_NUMBER, YEAR, MONTH,
-    NO_DAYS, dplyr::contains("LEVEL")
+    dly_levels,
+    STATION_NUMBER,
+    YEAR,
+    MONTH,
+    NO_DAYS,
+    dplyr::contains("LEVEL")
   )
   dly_levels <- dplyr::collect(dly_levels)
 
@@ -90,52 +102,92 @@ hy_daily_levels <- function(station_number = NULL,
     stop("No level data for this station in HYDAT")
   }
 
-  dly_levels <- tidyr::gather(dly_levels, !!sym_variable, !!sym_temp, -(STATION_NUMBER:NO_DAYS))
-  dly_levels <- dplyr::mutate(dly_levels, DAY = as.numeric(gsub("LEVEL|LEVEL_SYMBOL", "", variable)))
-  dly_levels <- dplyr::mutate(dly_levels, variable = gsub("[0-9]+", "", variable))
+  dly_levels <- tidyr::gather(
+    dly_levels,
+    !!sym_variable,
+    !!sym_temp,
+    -(STATION_NUMBER:NO_DAYS)
+  )
+  dly_levels <- dplyr::mutate(
+    dly_levels,
+    DAY = as.numeric(gsub("LEVEL|LEVEL_SYMBOL", "", variable))
+  )
+  dly_levels <- dplyr::mutate(
+    dly_levels,
+    variable = gsub("[0-9]+", "", variable)
+  )
   dly_levels <- tidyr::spread(dly_levels, variable, temp)
   dly_levels <- dplyr::mutate(dly_levels, LEVEL = as.numeric(LEVEL))
   ## No days that exceed actual number of days in the month
   dly_levels <- dplyr::filter(dly_levels, DAY <= NO_DAYS)
 
   ## convert into R date.
-  dly_levels <- dplyr::mutate(dly_levels, Date = lubridate::ymd(paste0(YEAR, "-", MONTH, "-", DAY)))
+  dly_levels <- dplyr::mutate(
+    dly_levels,
+    Date = lubridate::ymd(paste0(YEAR, "-", MONTH, "-", DAY))
+  )
 
   ## Then when a date column exist fine tune the subset
-  if (!dates_null[["start_is_null"]]) dly_levels <- dplyr::filter(dly_levels, !!sym_Date >= start_date)
-  if (!dates_null[["end_is_null"]]) dly_levels <- dplyr::filter(dly_levels, !!sym_Date <= end_date)
+  if (!dates_null[["start_is_null"]])
+    dly_levels <- dplyr::filter(dly_levels, !!sym_Date >= start_date)
+  if (!dates_null[["end_is_null"]])
+    dly_levels <- dplyr::filter(dly_levels, !!sym_Date <= end_date)
 
-
-  dly_levels <- dplyr::left_join(dly_levels, tidyhydat::hy_data_symbols, by = c("LEVEL_SYMBOL" = "SYMBOL_ID"))
+  dly_levels <- dplyr::left_join(
+    dly_levels,
+    tidyhydat::hy_data_symbols,
+    by = c("LEVEL_SYMBOL" = "SYMBOL_ID")
+  )
   dly_levels <- dplyr::mutate(dly_levels, Parameter = "Level")
 
   ## Control for symbol ouput
   if (symbol_output == "code") {
     dly_levels <- dplyr::select(
-      dly_levels, STATION_NUMBER, Date, Parameter,
-      LEVEL, LEVEL_SYMBOL
+      dly_levels,
+      STATION_NUMBER,
+      Date,
+      Parameter,
+      LEVEL,
+      LEVEL_SYMBOL
     )
   }
 
   if (symbol_output == "english") {
     dly_levels <- dplyr::select(
-      dly_levels, STATION_NUMBER, Date, Parameter,
-      LEVEL, SYMBOL_EN
+      dly_levels,
+      STATION_NUMBER,
+      Date,
+      Parameter,
+      LEVEL,
+      SYMBOL_EN
     )
   }
 
   if (symbol_output == "french") {
     dly_levels <- dplyr::select(
-      dly_levels, STATION_NUMBER, Date, Parameter,
-      LEVEL, SYMBOL_FR
+      dly_levels,
+      STATION_NUMBER,
+      Date,
+      Parameter,
+      LEVEL,
+      SYMBOL_FR
     )
   }
 
   dly_levels <- dplyr::arrange(dly_levels, Date)
 
-  colnames(dly_levels) <- c("STATION_NUMBER", "Date", "Parameter", "Value", "Symbol")
+  colnames(dly_levels) <- c(
+    "STATION_NUMBER",
+    "Date",
+    "Parameter",
+    "Value",
+    "Symbol"
+  )
 
-  attr(dly_levels, "missed_stns") <- setdiff(unique(stns), unique(dly_levels$STATION_NUMBER))
+  attr(dly_levels, "missed_stns") <- setdiff(
+    unique(stns),
+    unique(dly_levels$STATION_NUMBER)
+  )
 
   as.hy(dly_levels)
 }
