@@ -39,13 +39,13 @@
 #' @source HYDAT
 #' @export
 
-
-
-hy_sed_daily_loads <- function(station_number = NULL,
-                               hydat_path = NULL,
-                               prov_terr_state_loc = NULL,
-                               start_date = NULL,
-                               end_date = NULL) {
+hy_sed_daily_loads <- function(
+  station_number = NULL,
+  hydat_path = NULL,
+  prov_terr_state_loc = NULL,
+  start_date = NULL,
+  end_date = NULL
+) {
   ## Determine which dates should be queried
   dates_null <- date_check(start_date, end_date)
 
@@ -72,12 +72,24 @@ hy_sed_daily_loads <- function(station_number = NULL,
   ## Do the initial subset to take advantage of dbplyr only issuing sql query when it has too
 
   ## by year
-  if (!dates_null[["start_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_YEAR >= lubridate::year(start_date))
-  if (!dates_null[["end_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_YEAR <= lubridate::year(end_date))
+  if (!dates_null[["start_is_null"]])
+    sed_dly_loads <- dplyr::filter(
+      sed_dly_loads,
+      !!sym_YEAR >= lubridate::year(start_date)
+    )
+  if (!dates_null[["end_is_null"]])
+    sed_dly_loads <- dplyr::filter(
+      sed_dly_loads,
+      !!sym_YEAR <= lubridate::year(end_date)
+    )
 
   sed_dly_loads <- dplyr::select(
-    sed_dly_loads, STATION_NUMBER, YEAR, MONTH,
-    NO_DAYS, dplyr::contains("LOAD")
+    sed_dly_loads,
+    STATION_NUMBER,
+    YEAR,
+    MONTH,
+    NO_DAYS,
+    dplyr::contains("LOAD")
   )
   sed_dly_loads <- dplyr::collect(sed_dly_loads)
 
@@ -85,29 +97,54 @@ hy_sed_daily_loads <- function(station_number = NULL,
     stop("No sediment load data for this station in HYDAT")
   }
 
-  sed_dly_loads <- tidyr::gather(sed_dly_loads, !!sym_variable, !!sym_temp, -(STATION_NUMBER:NO_DAYS))
-  sed_dly_loads <- dplyr::mutate(sed_dly_loads, DAY = as.numeric(gsub("LOAD", "", variable)))
-  sed_dly_loads <- dplyr::mutate(sed_dly_loads, variable = gsub("[0-9]+", "", variable))
+  sed_dly_loads <- tidyr::gather(
+    sed_dly_loads,
+    !!sym_variable,
+    !!sym_temp,
+    -(STATION_NUMBER:NO_DAYS)
+  )
+  sed_dly_loads <- dplyr::mutate(
+    sed_dly_loads,
+    DAY = as.numeric(gsub("LOAD", "", variable))
+  )
+  sed_dly_loads <- dplyr::mutate(
+    sed_dly_loads,
+    variable = gsub("[0-9]+", "", variable)
+  )
   sed_dly_loads <- tidyr::spread(sed_dly_loads, !!sym_variable, !!sym_temp)
   sed_dly_loads <- dplyr::mutate(sed_dly_loads, LOAD = as.numeric(LOAD))
   ## No days that exceed actual number of days in the month
   sed_dly_loads <- dplyr::filter(sed_dly_loads, DAY <= NO_DAYS)
 
   ## convert into R date.
-  sed_dly_loads <- dplyr::mutate(sed_dly_loads, Date = lubridate::ymd(
-    paste0(YEAR, "-", MONTH, "-", DAY)
-  ))
+  sed_dly_loads <- dplyr::mutate(
+    sed_dly_loads,
+    Date = lubridate::ymd(
+      paste0(YEAR, "-", MONTH, "-", DAY)
+    )
+  )
 
   ## Then when a date column exist fine tune the subset
-  if (!dates_null[["start_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_Date >= start_date)
-  if (!dates_null[["end_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_Date <= end_date)
+  if (!dates_null[["start_is_null"]])
+    sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_Date >= start_date)
+  if (!dates_null[["end_is_null"]])
+    sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_Date <= end_date)
 
   sed_dly_loads <- dplyr::mutate(sed_dly_loads, Parameter = "Load")
-  sed_dly_loads <- dplyr::select(sed_dly_loads, STATION_NUMBER, Date, Parameter, LOAD)
+  sed_dly_loads <- dplyr::select(
+    sed_dly_loads,
+    STATION_NUMBER,
+    Date,
+    Parameter,
+    LOAD
+  )
   sed_dly_loads <- dplyr::arrange(sed_dly_loads, Date)
 
   colnames(sed_dly_loads) <- c("STATION_NUMBER", "Date", "Parameter", "Value")
 
-  attr(sed_dly_loads, "missed_stns") <- setdiff(unique(stns), unique(sed_dly_loads$STATION_NUMBER))
+  attr(sed_dly_loads, "missed_stns") <- setdiff(
+    unique(stns),
+    unique(sed_dly_loads$STATION_NUMBER)
+  )
   as.hy(sed_dly_loads)
 }
