@@ -41,13 +41,13 @@
 #' @source HYDAT
 #' @export
 
-
-
-hy_sed_samples_psd <- function(station_number = NULL,
-                               hydat_path = NULL,
-                               prov_terr_state_loc = NULL,
-                               start_date = NULL,
-                               end_date = NULL) {
+hy_sed_samples_psd <- function(
+  station_number = NULL,
+  hydat_path = NULL,
+  prov_terr_state_loc = NULL,
+  start_date = NULL,
+  end_date = NULL
+) {
   ## Determine which dates should be queried
   dates_null <- date_check(start_date, end_date)
 
@@ -66,25 +66,51 @@ hy_sed_samples_psd <- function(station_number = NULL,
 
   ## Data manipulations
   sed_samples_psd <- dplyr::tbl(hydat_con, "SED_SAMPLES_PSD")
-  sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym_STATION_NUMBER %in% stns)
-  sed_samples_psd <- dplyr::left_join(sed_samples_psd, dplyr::tbl(hydat_con, "SED_DATA_TYPES"), by = c("SED_DATA_TYPE"))
+  sed_samples_psd <- dplyr::filter(
+    sed_samples_psd,
+    !!sym_STATION_NUMBER %in% stns
+  )
+  sed_samples_psd <- dplyr::left_join(
+    sed_samples_psd,
+    dplyr::tbl(hydat_con, "SED_DATA_TYPES"),
+    by = c("SED_DATA_TYPE")
+  )
 
   sed_samples_psd <- dplyr::collect(sed_samples_psd)
 
-  if (is.data.frame(sed_samples_psd) && nrow(sed_samples_psd) == 0) stop("This station is not present in HYDAT")
+  if (is.data.frame(sed_samples_psd) && nrow(sed_samples_psd) == 0)
+    stop("This station is not present in HYDAT")
 
-  sed_samples_psd <- dplyr::mutate(sed_samples_psd, DATE = lubridate::ymd_hms(DATE), date_no_time = as.Date(DATE))
-
-  ## SUBSET by date
-  if (!dates_null[["start_is_null"]]) sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym("date_no_time") >= as.Date(start_date))
-  if (!dates_null[["end_is_null"]]) sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym("date_no_time") <= as.Date(end_date))
-
-
-  sed_samples_psd <- dplyr::select(sed_samples_psd, STATION_NUMBER,
-    SED_DATA_TYPE = SED_DATA_TYPE_EN,
-    Date = DATE, PARTICLE_SIZE, PERCENT
+  sed_samples_psd <- dplyr::mutate(
+    sed_samples_psd,
+    DATE = lubridate::ymd_hms(DATE),
+    date_no_time = as.Date(DATE)
   )
 
-  attr(sed_samples_psd, "missed_stns") <- setdiff(unique(stns), unique(sed_samples_psd$STATION_NUMBER))
+  ## SUBSET by date
+  if (!dates_null[["start_is_null"]])
+    sed_samples_psd <- dplyr::filter(
+      sed_samples_psd,
+      !!sym("date_no_time") >= as.Date(start_date)
+    )
+  if (!dates_null[["end_is_null"]])
+    sed_samples_psd <- dplyr::filter(
+      sed_samples_psd,
+      !!sym("date_no_time") <= as.Date(end_date)
+    )
+
+  sed_samples_psd <- dplyr::select(
+    sed_samples_psd,
+    STATION_NUMBER,
+    SED_DATA_TYPE = SED_DATA_TYPE_EN,
+    Date = DATE,
+    PARTICLE_SIZE,
+    PERCENT
+  )
+
+  attr(sed_samples_psd, "missed_stns") <- setdiff(
+    unique(stns),
+    unique(sed_samples_psd$STATION_NUMBER)
+  )
   as.hy(sed_samples_psd)
 }
