@@ -10,7 +10,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and limitations under the License.
 
-
 #' Download a tibble of realtime river data from the last 30 days from the Meteorological Service of Canada datamart
 #'
 #' Download realtime river data from the last 30 days from the Meteorological Service of Canada (MSC) datamart.
@@ -128,7 +127,6 @@ realtime_stations <- function(prov_terr_state_loc = NULL) {
     return(net_tibble)
   }
 
-
   as.realtime(net_tibble[net_tibble$PROV_TERR_STATE_LOC %in% prov, ])
 }
 
@@ -154,12 +152,22 @@ realtime_stations <- function(prov_terr_state_loc = NULL) {
 #'
 #' @export
 realtime_add_local_datetime <- function(.data, set_tz = NULL) {
-  timezone_data <- dplyr::left_join(.data, tidyhydat::allstations[, c("STATION_NUMBER", "station_tz")], by = c("STATION_NUMBER"))
+  timezone_data <- dplyr::left_join(
+    .data,
+    tidyhydat::allstations[, c("STATION_NUMBER", "station_tz")],
+    by = c("STATION_NUMBER")
+  )
 
   tz_used <- names(sort(table(timezone_data$station_tz), decreasing = TRUE)[1])
 
   if (dplyr::n_distinct(timezone_data$station_tz) > 1) {
-    warning(paste0("Multiple timezones detected. All times in local_time have been adjusted to ", tz_used), call. = FALSE)
+    warning(
+      paste0(
+        "Multiple timezones detected. All times in local_time have been adjusted to ",
+        tz_used
+      ),
+      call. = FALSE
+    )
   }
 
   if (!is.null(set_tz)) {
@@ -167,13 +175,22 @@ realtime_add_local_datetime <- function(.data, set_tz = NULL) {
     tz_used <- set_tz
   }
 
-  timezone_data$local_datetime <- lubridate::with_tz(timezone_data$Date, tz = tz_used)
+  timezone_data$local_datetime <- lubridate::with_tz(
+    timezone_data$Date,
+    tzone = tz_used
+  )
 
   timezone_data$tz_used <- tz_used
 
   dplyr::select(
-    timezone_data, STATION_NUMBER, PROV_TERR_STATE_LOC, Date,
-    station_tz, local_datetime, tz_used, dplyr::everything()
+    timezone_data,
+    STATION_NUMBER,
+    PROV_TERR_STATE_LOC,
+    Date,
+    station_tz,
+    local_datetime,
+    tz_used,
+    dplyr::everything()
   )
 }
 
@@ -195,11 +212,17 @@ realtime_add_local_datetime <- function(.data, set_tz = NULL) {
 realtime_daily_mean <- function(.data, na.rm = FALSE) {
   df_mean <- dplyr::mutate(.data, Date = as.Date(Date))
 
-  df_mean <- dplyr::group_by(df_mean, STATION_NUMBER, PROV_TERR_STATE_LOC, Date, Parameter)
+  df_mean <- dplyr::group_by(
+    df_mean,
+    STATION_NUMBER,
+    PROV_TERR_STATE_LOC,
+    Date,
+    Parameter
+  )
 
   df_mean <- dplyr::summarise(df_mean, Value = mean(Value, na.rm = na.rm))
 
   df_mean <- dplyr::arrange(df_mean, Parameter)
 
   dplyr::ungroup(df_mean)
-}
\ No newline at end of file
+}
