@@ -1,33 +1,45 @@
 test_that("hy_annual_instant_peaks accepts single and multiple province arguments", {
   stns <- "08NM083"
-  expect_identical(unique(
-    hy_annual_instant_peaks(
-      station_number = stns,
-      hydat_path = hy_test_db()
-    )$STATION_NUMBER
-  ), stns)
-  expect_identical(length(unique(
-    hy_annual_instant_peaks(
-      station_number = c("08NM083", "08NE102"),
-      hydat_path = hy_test_db()
-    )$STATION_NUMBER
-  )), length(c("08NM083", "08NE102")))
+  expect_identical(
+    unique(
+      hy_annual_instant_peaks(
+        station_number = stns,
+        hydat_path = hy_test_db()
+      )$STATION_NUMBER
+    ),
+    stns
+  )
+  expect_identical(
+    length(unique(
+      hy_annual_instant_peaks(
+        station_number = c("08NM083", "08NE102"),
+        hydat_path = hy_test_db()
+      )$STATION_NUMBER
+    )),
+    length(c("08NM083", "08NE102"))
+  )
 })
 
 
 test_that("hy_annual_instant_peaks accepts single and multiple province arguments", {
-  expect_true(nrow(
-    hy_annual_instant_peaks(
-      prov_terr_state_loc = "BC",
-      hydat_path = hy_test_db()
-    )
-  ) >= 1)
-  expect_true(nrow(
-    hy_annual_instant_peaks(
-      prov_terr_state_loc = c("BC", "YT"),
-      hydat_path = hy_test_db()
-    )
-  ) >= 1)
+  expect_true(
+    nrow(
+      hy_annual_instant_peaks(
+        prov_terr_state_loc = "BC",
+        hydat_path = hy_test_db()
+      )
+    ) >=
+      1
+  )
+  expect_true(
+    nrow(
+      hy_annual_instant_peaks(
+        prov_terr_state_loc = c("BC", "YT"),
+        hydat_path = hy_test_db()
+      )
+    ) >=
+      1
+  )
 })
 
 test_that("hy_annual_instant_peaks produces an error when a province is not specified correctly", {
@@ -44,9 +56,12 @@ test_that("hy_annual_instant_peaks produces an error when a province is not spec
 ## TODO add test for CA
 
 test_that("hy_annual_instant_peaks gather data when no arguments are supplied", {
-  expect_true(nrow(hy_annual_instant_peaks(
-    hydat_path = hy_test_db()
-  )) >= 1)
+  expect_true(
+    nrow(hy_annual_instant_peaks(
+      hydat_path = hy_test_db()
+    )) >=
+      1
+  )
 })
 
 
