@@ -41,7 +41,8 @@ test_that("pull_station_number fails when a dataframe doesn't contain a STATION_
 
 test_that("pull_station_number grabs station number successfully", {
   stns <- c("08NM083", "08NE102")
-  pulled_stns <- hy_annual_stats(stns, hydat_path = hy_test_db()) |> pull_station_number()
+  pulled_stns <- hy_annual_stats(stns, hydat_path = hy_test_db()) |>
+    pull_station_number()
   expect_identical(stns, unique(pulled_stns))
 })
 
